{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for ISO C++.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/isocpp.xml and 'make bootstrap'.
module Skylighting.Syntax.Isocpp (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for ISO C++.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisocpp.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsocpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL@\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB(?:#|%\\:|\\?\\?=)\\s*(?=.)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreprocessorCmd\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AfterHashLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AfterHashLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AfterHashLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\SO\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^\\\\]+\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifndef\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQendif\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awarning\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcmakedefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcmakedefine01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2carries_dependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeprecated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfallthrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlikely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaybe_unused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1no_unique_address\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnodiscard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunlikely\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH]]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL,\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN:(){}[].+-/*%=<>!|&?~^\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttributeNamespace\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DetectGccAttributes\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4[A-Z][A-Z0-9_]{2,}\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttributeNamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttributeNamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSDetectNamespaceGccAttributes\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar16 Literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar16 Literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULA\\\\(?:[tnvbrfa'\"\\\\?]|[0-7]{1,3}|x[0-9A-Fa-f]{1,4}|u[0-9A-Fa-f]{4})\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL'\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar32 Literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar32 Literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULQ\\\\(?:[tnvbrfa'\"\\\\?]|[0-7]{1,3}|x[0-9A-Fa-f]{1,8}|u[0-9A-Fa-f]{4}|U[0-9A-Fa-f]{8})\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL'\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rChar8 Literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rChar8 Literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\\\\(?:[tnvbrfa'\"\\\\?]|[0-7]{1,3}|x[0-9A-Fa-f]{1,2})\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL'\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Char Literal Close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckUDLOperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckUDLOperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLOperatorName\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SO\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDoxygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGNUMacros\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIn Define\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btemplate\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,;\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB(){}[].+-/*%=<>!|&?~^  \RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfFlL\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB(?:i[fl]?|min|[mun]?s|h)\\b\SOH\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL_\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIdentifierError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIdentifierError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.[^\\s()]*\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIn Define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIn Define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\DLE\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX{}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH[[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\.?[0-9]\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,;\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN:(){}[].+-/*%=<>!|&?~^\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmatch string\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDetectGccExtensionsInPP\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstd::\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStandard Classes In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboost::\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBOOST_\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdetail::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdetails::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaux::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinternals::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__VA_ARGS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__VA_OPT__\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$@`\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^%)]+\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)%(?:ll?|[zjtL]|hh?)?[diouxXeEfFgGaAcspn%]\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT)%1\"\b\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\ETX<>\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI(?:#|%\\:|\\?\\?=)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Inscoped AfterHash\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Inscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Inscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS(?:#|%\\:|\\?\\?=)\\s*el(?:se|if)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutscoped 2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(?:#|%\\:|\\?\\?=)\\s*endif\\b\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruUlLimunshyd_\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntSuffixPattern\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS[Uu][Ll]{0,2}|[Ll]{0,2}[Uu]?\SOH\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS(?:i[fl]?|min|[mun]?s|[hyd])\\b\SOH\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL_\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'0[xX](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]+)*)\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK0[Bb][01](?:'?[01]+)*\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO0(?:'?[0-7]+)+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!0(?![xXbB0-9])|[1-9](?:'?[0-9]+)*\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI[._0-9A-Za-z']+\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH[[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\.?[0-9]\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,;\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN:(){}[].+-/*%=<>!|&?~^\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmatch string\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DetectGccExtensions\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstd::\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStandard Classes\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboost::\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBOOST_\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdetail::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdetails::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaux::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinternals::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI(?:#|%\\:|\\?\\?=)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$@`\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDoxygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 1\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a//BEGIN\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ//END\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\158\\.(?:[0-9](?:'?[0-9]+)*)(?:[eE][+-]?(?:[0-9](?:'?[0-9]+)*))?|(?:[0-9](?:'?[0-9]+)*)(?:(?:[eE][+-]?(?:[0-9](?:'?[0-9]+)*))|\\.(?:[0-9](?:'?[0-9]+)*)?(?:[eE][+-]?(?:[0-9](?:'?[0-9]+)*))?)|0[xX](?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]+)*)(?:[pP][-+]?(?:[0-9](?:'?[0-9]+)*))?|(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]+)*)(?:(?:[pP][-+]?(?:[0-9](?:'?[0-9]+)*))|\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]+)*)?(?:[pP][-+]?(?:[0-9](?:'?[0-9]+)*))?))\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\.[_0-9A-Za-z]*|[_0-9A-Za-z]+\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v_[eEpP][+-]\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO_[_[:alnum:]]*\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOutscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOutscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI(?:#|%\\:|\\?\\?=)\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Outscoped AfterHash\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutscoped 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutscoped 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB(?:#|%\\:|\\?\\?=)\\s*endif\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Outscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Outscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(?:#|%\\:|\\?\\?=)\\s*endif\\b\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*else\\b\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4(?:#|%\\:|\\?\\?=)\\s*if\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULe(?:#|%\\:|\\?\\?=)\\s*elif\\s+(?:1|true)\\s*(\\|\\|([^/]|/[^*/])+)?($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULQ(?:#|%\\:|\\?\\?=)\\s*elif\\s+(?:0|false)\\s*($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*elif\\b\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2(?:#|%\\:|\\?\\?=)\\s*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4(?:#|%\\:|\\?\\?=)\\s*if\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\SO\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4(?:#|%\\:|\\?\\?=)\\s*if\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC(?:#|%\\:|\\?\\?=)\\s*el(se|if)\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB(?:#|%\\:|\\?\\?=)\\s*endif\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_DEFAULT_NEW_ALIGNMENT__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_STRICT_POINTER_SAFETY__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDCPP_THREADS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI__STDC_HOSTED__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDC_ISO_10646__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN__STDC_MB_MIGHT_NEQ_WC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE__STDC_VERSION__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__STDC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__TIME__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__cplusplus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__func__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__has_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGNUMacros\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreprocessorCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreprocessorCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifndef\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQendif\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awarning\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcmakedefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcmakedefine01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finclude_next\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[0-9]+\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AfterHashLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULR\\w+\\s+(?:1|true)\\s*(\\|\\|([^/]|/[^*/])+)?($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\\w+\\s+(?:0|false)\\s*($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOutscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\w+\\s+(?=[^\\s])\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\w+\\s+([_A-Za-z][A-Za-z0-9]*\\s*|(?=//|/\\*))\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI([^\\(]{0,16})\\(\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInRawString\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStandard Classes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStandard Classes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStandard Classes In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStandard Classes In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\x[0-9A-Fa-f]{1,8}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\x[0-9A-Fa-f]{1,4}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\x[0-9A-Fa-f]{1,8}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\x[0-9A-Fa-f]{1,2}\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI[0-9A-Fa-f]{1,}\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLOperatorName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLOperatorName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_[_[:alnum:]]*\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIdentifierError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLStringSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLStringSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsv\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHs\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_[_0-9A-Za-z]*\\b\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH//\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpos_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tptrdiff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsig_atomic_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtime_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ava_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awchar_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwint_t\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fthread_local\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\CAN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_DEFAULT_NEW_ALIGNMENT__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_STRICT_POINTER_SAFETY__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDCPP_THREADS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI__STDC_HOSTED__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDC_ISO_10646__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN__STDC_MB_MIGHT_NEQ_WC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE__STDC_VERSION__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__STDC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__TIME__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__cplusplus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__func__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__has_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL(_[a-zA-Z0-9_]+|[a-zA-Z][a-zA-Z0-9_]*__\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%m_[a-zA-Z0-9_]+|[a-z][a-zA-Z0-9_]*_\\b\SOH\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIg_[a-zA-Z0-9_]+\SOH\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIs_[a-zA-Z0-9_]+\SOH\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4[A-Z][A-Z0-9_]{2,}\\b\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US[a-zA-Z][a-zA-Z0-9_]*_t(ype)?\\b\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckUDLOperator\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKand_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTauto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcompl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconst_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconstexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdecltype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdynamic_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexplicit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfriend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnot_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anullptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQor_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreinterpret_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brequires\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsizeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstatic_assert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstatic_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btypename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxor_eq\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmatch string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmatch string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\SOHU\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString32\SOHu\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\SOHL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu8\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\SOHR\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuR\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXUR\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLR\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTu8R\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rChar8 Literal\SOHL'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar16 Literal\SOHu'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar16 Literal\SOHU'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOChar32 Literal\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu8'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rChar8 Literal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b[^%\\\\\"]+\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLStringSuffix\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULi\\\\(?:[tnvbrfa'\"\\\\?]|[0-7]{1,3}|u[0-9A-Fa-f]{4}|U[0-9A-Fa-f]{8})|%(?:ll?|[zjtL]|hh?)?[diouxXeEfFgGaAcspn%]\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\\\(?:u[^\"]{0,3}|U[^\"]{0,7}|.)\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USAlex Turbov (i.zaufi@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX14\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.c++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.cc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.h\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.hh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.H\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.h++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.hxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.hpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.hcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.moc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain"
